@@ -55,8 +55,8 @@ class CryptoComApi:
     error = None
 
     def __init__(self, key=None, secret=None, version=ApiVersion.V1):
-        self.version = version
-        self.API_ROOT = self._API_VERSION_ROOT_PATH[version]
+        self.version = CryptoComApi.ApiVersion(version)
+        self.API_ROOT = self._API_VERSION_ROOT_PATH[self.version]
 
         logger.debug(f"API version {version} initialized, root path is: {self.API_ROOT}")
 
@@ -165,13 +165,15 @@ class CryptoComApi:
             # nonce = int(time() * 1000)
             id = 1
             nonce = current_timestamp()
-            params['sig'] = self._sign(params, method=path, id=id, nonce=nonce)
-            params['params'] = {}
-            params['api_key'] = self.__key
-            params['method'] = path
-            params['nonce'] = nonce
-            params['id'] = id
-            return self._request(path, params, method='post')
+            sig = self._sign(params, method=path, id=id, nonce=nonce)
+            param = {
+                'params': params,
+                'sig': sig,
+                'api_key': self.__key,
+                'method': path,
+                'nonce': nonce,
+                'id': id}
+            return self._request(path, param, method='post')
 
         return self._request(path, params, method='post')
 
@@ -433,7 +435,7 @@ class CryptoComApi:
         }
         return self._post(path[self.version], params=param[self.version])
 
-    def open_orders(self, symbol, page_size=None, page_number=None):
+    def open_orders(self, symbol=None, page_size=None, page_number=None):
         """
         List all open orders in a particular market
 
@@ -448,7 +450,7 @@ class CryptoComApi:
         }
         param = {
             CryptoComApi.ApiVersion.V1: {'symbol': symbol},
-            CryptoComApi.ApiVersion.V2: {'instrument_name': symbol}
+            CryptoComApi.ApiVersion.V2: ({'instrument_name': symbol} if symbol else {})
         }
 
         if page_size:
